Learn R Programming

LDM (version 6.0.1)

throat.meta: Metadata of the throat microbiome samples

Description

This data set includes samples from the microbiome of the nasopharynx and oropharynx on each side of the body. It were generated to study the effect of smoking on the microbiota of the upper respiratory tract in 60 individuals, 28 smokers and 32 nonsmokers.

Usage

data("throat.meta")

Arguments

Format

A data frame with 60 observations on 16 variables.

References

R package "GUniFrac"

Examples

Run this code
data(throat.meta)

Run the code above in your browser using DataLab