Expected unweighted UniFrac distance matrix by the first order approixmation.
unifrac.mean.o2
Expected unweighted UniFrac distance matrix by the second order approixmation.
unifrac.mean.sq.o1
Expected squared unweighted UniFrac distance matrix by the first order approixmation.
unifrac.mean.sq.o2
Expected squared unweighted UniFrac distance matrix by the second order approixmation.
Arguments
otu.table
the n.obs by n.otu matrix of read counts.
tree
the phylogeneic tree.
rarefy.depth
rarefaction depth. The default is the minimum library size observed in the OTU table.
first.order.approx.only
a logical value indicating whether to calculate the expected value
using the first order approixmation by the delta method. The default is FALSE,
using the second order approixmation.
verbose
a logical value indicating whether to generate verbose output. Default is TRUE.
Author
Yi-Juan Hu <yijuan.hu@emory.edu>, Glen A. Satten <gsatten@emory.edu>