Expected Jaccard distance matrix by the first order approixmation.
jac.mean.o2
Expected Jaccard distance matrix by the second order approixmation.
jac.mean.sq.o1
Expected squared Jaccard distance matrix by the first order approixmation.
jac.mean.sq.o2
Expected squared Jaccard distance matrix by the second order approixmation.
Arguments
otu.table
the n.obs by n.otu matrix of read counts.
rarefy.depth
rarefaction depth. The default is the minimum library size observed in the OTU table.
first.order.approx.only
a logical value indicating whether to calculate the expected value
using the first order approixmation by the delta method.
The default is FALSE, using the second order approixmation.
Author
Yi-Juan Hu <yijuan.hu@emory.edu>, Glen A. Satten <gsatten@emory.edu>